@@ -252,7 +252,9 @@ public:
     void set_option_from_ui_item(GncOption& option) noexcept override
     {
         auto widget{GTK_TEXT_VIEW(get_widget())};
-        option.set_value(std::string{xxxgtk_textview_get_text(widget)});
+        auto str{xxxgtk_textview_get_text(widget)};
+        option.set_value(std::string{str});
+        g_free (str);
     }
 };
 
@@ -522,7 +524,7 @@ RelativeDateEntry::RelativeDateEntry(GncOption& option)
         GtkTreeIter  iter;
         gtk_list_store_append (store, &iter);
         gtk_list_store_set (store, &iter, 0,
-                            option.permissible_value_name(index), -1);
+                            _(option.permissible_value_name(index)), -1);
     }
 
     /* Create the new Combo with tooltip and add the store */
@@ -945,7 +947,7 @@ create_account_widget(GncOption& option, char *name)
 
         for (i = 0; i < NUM_ACCOUNT_TYPES; i++)
             avi.include_type[i] = FALSE;
-        avi.show_hidden = FALSE;
+        avi.show_hidden = TRUE;
 
         for (node = acct_type_list; node; node = node->next)
         {
@@ -966,7 +968,7 @@ create_account_widget(GncOption& option, char *name)
 
         for (i = 0; i < NUM_ACCOUNT_TYPES; i++)
             avi.include_type[i] = TRUE;
-        avi.show_hidden = FALSE;
+        avi.show_hidden = TRUE;
         gnc_tree_view_account_set_view_info (GNC_TREE_VIEW_ACCOUNT (tree), &avi);
     }
 
@@ -1031,7 +1033,7 @@ create_account_widget(GncOption& option, char *name)
     button = gtk_check_button_new_with_label(_("Show Hidden Accounts"));
     gtk_box_pack_start(GTK_BOX(bbox), button, FALSE, FALSE, 0);
     gtk_widget_set_tooltip_text(button, _("Show accounts that have been marked hidden."));
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), FALSE);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
     g_signal_connect(G_OBJECT(button), "toggled",
                      G_CALLBACK(show_hidden_toggled_cb), &option);
 
@@ -1080,7 +1082,8 @@ public:
     void set_option_from_ui_item(GncOption& option) noexcept override
     {
         auto widget{GNC_ACCOUNT_SEL(get_widget())};
-        option.set_value(qof_instance_cast((gnc_account_sel_get_account(widget))));
+// Must cast it to const Account* to get the template specialization to recognize it.
+        option.set_value(static_cast<const Account*>(gnc_account_sel_get_account(widget)));
     }
 };
 
@@ -1101,6 +1104,10 @@ create_option_widget<GncOptionUIType::ACCOUNT_SEL> (GncOption& option,
     g_signal_connect(widget, "account_sel_changed",
                      G_CALLBACK(gnc_option_changed_widget_cb), &option);
     wrap_widget(option, widget, page_box, row);
+    // wrap_widget sets the parent so this comes after.
+    gtk_container_child_set(GTK_CONTAINER(gtk_widget_get_parent(widget)),
+                            widget, "fill", TRUE, "expand", TRUE,
+                            nullptr);
 }
 
 static void
@@ -1150,10 +1157,12 @@ class GncGtkListUIItem : public GncOptionGtkUIItem
 public:
     GncGtkListUIItem(GtkWidget* widget) :
         GncOptionGtkUIItem{widget, GncOptionUIType::LIST} {}
+
     void set_ui_item_from_option(GncOption& option) noexcept override
     {
         auto widget{GTK_TREE_VIEW(get_widget())};
         auto selection{gtk_tree_view_get_selection(widget)};
+        gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
         g_signal_handlers_block_by_func(selection, (gpointer)list_changed_cb, &option);
         gtk_tree_selection_unselect_all(selection);
         for (auto index : option.get_value<GncMultichoiceOptionIndexVec>())
@@ -1164,20 +1173,20 @@ public:
         }
         g_signal_handlers_unblock_by_func(selection, (gpointer)list_changed_cb, &option);
     }
+
     void set_option_from_ui_item(GncOption& option) noexcept override
     {
         auto widget{GTK_TREE_VIEW(get_widget())};
         auto selection{gtk_tree_view_get_selection(widget)};
-        auto rows{option.num_permissible_values()};
+        auto selected_rows{gtk_tree_selection_get_selected_rows(selection, nullptr)};
         GncMultichoiceOptionIndexVec vec;
-        for (size_t row = 0; row < rows; ++row)
+        for (auto row = selected_rows; row; row = g_list_next(row))
         {
-            auto path{gtk_tree_path_new_from_indices(row, -1)};
-            auto selected{gtk_tree_selection_path_is_selected(selection, path)};
-            gtk_tree_path_free(path);
-            if (selected)
-                vec.push_back(row);
+            auto path{static_cast<GtkTreePath*>(row->data)};
+            auto indices{gtk_tree_path_get_indices(path)};
+            vec.push_back(*indices);
         }
+        g_list_free_full(selected_rows, (GDestroyNotify)gtk_tree_path_free);
         option.set_value(vec);
     }
 };
@@ -1269,19 +1278,21 @@ public:
         GncOptionGtkUIItem{widget, GncOptionUIType::NUMBER_RANGE} {}
     void set_ui_item_from_option(GncOption& option) noexcept override
     {
+        double value;
         if (option.is_alternate())
-            gtk_spin_button_set_value(GTK_SPIN_BUTTON(get_widget()),
-                                      option.get_value<int>());
+            value = static_cast<double>(option.get_value<int>());
         else
-            gtk_spin_button_set_value(GTK_SPIN_BUTTON(get_widget()),
-                                      option.get_value<double>());
+            value = option.get_value<double>();
+
+        gtk_spin_button_set_value(GTK_SPIN_BUTTON(get_widget()), value);
     }
     void set_option_from_ui_item(GncOption& option) noexcept override
     {
+        auto value{gtk_spin_button_get_value(GTK_SPIN_BUTTON(get_widget()))};
         if (option.is_alternate())
-            option.set_value<int>(gtk_spin_button_get_value(GTK_SPIN_BUTTON(get_widget())));
+            option.set_value<int>(static_cast<int>(value));
         else
-            option.set_value<double>(gtk_spin_button_get_value(GTK_SPIN_BUTTON(get_widget())));
+            option.set_value<double>(value);
     }
 };
 
@@ -1675,13 +1686,21 @@ public:
     void set_ui_item_from_option(GncOption& option) noexcept override
     {
         auto widget{GNC_DATE_FORMAT(get_widget())};
-        gnc_date_format_set_custom(widget,
-                                   option.get_value<std::string>().c_str());
+        auto [format, months, years, custom] = option.get_value<GncOptionDateFormat>();
+        gnc_date_format_set_format(widget, format);
+        gnc_date_format_set_months(widget, months);
+        gnc_date_format_set_years(widget, years);
+        gnc_date_format_set_custom(widget, custom.c_str());
     }
     void set_option_from_ui_item(GncOption& option) noexcept override
     {
         auto widget{GNC_DATE_FORMAT(get_widget())};
-        option.set_value(std::string{gnc_date_format_get_custom(widget)});
+        GncOptionDateFormat format{
+            gnc_date_format_get_format(widget),
+            gnc_date_format_get_months(widget),
+            gnc_date_format_get_years(widget),
+            gnc_date_format_get_custom(widget)};
+        option.set_value(format);
     }
 };
 
